summaryrefslogtreecommitdiff
path: root/ace/Hash_Map_Manager.h
diff options
context:
space:
mode:
Diffstat (limited to 'ace/Hash_Map_Manager.h')
-rw-r--r--ace/Hash_Map_Manager.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/ace/Hash_Map_Manager.h b/ace/Hash_Map_Manager.h
index 3800b241b0f..d8c70e9b669 100644
--- a/ace/Hash_Map_Manager.h
+++ b/ace/Hash_Map_Manager.h
@@ -153,8 +153,10 @@ public:
protected:
// = The following methods do the actual work.
- // These methods assume that the locks are held by the private
- // methods.
+ size_t hash (const EXT_ID &ext_id);
+ // Compute the hash value of the <ext_id>.
+
+ // = These methods assume locks are held by private methods.
int bind_i (const EXT_ID &ext_id, const INT_ID &int_id);
// Performs the binding of <ext_id> to <int_id>. Must be